@@ -6,6 +6,7 @@ knitr::opts_chunk$set(
 library(hereR)
 library(data.table)
 library(mapview)
+mapviewOptions(fgb = FALSE)
 addresses <- poi$city
 geocoded <- hereR:::example$geocode
 suggestions <- hereR:::example$autocomplete
@@ -30,14 +31,14 @@ head(geocoded, 3)
 #  locs <- geocode(df$address)
 #  geocoded_sfdf <- st_as_sf(data.frame(locs, df[locs$id, ]))
 
-## ----map_geocoded, eval=TRUE, out.width='100%'--------------------------------
-mapview(geocoded,
-        label = geocoded$address,
-        col.regions = "yellow",
-        map.types = c("Esri.WorldTopoMap"),
-        legend = FALSE,
-        homebutton = FALSE
-)
+## ----map_geocoded, eval=FALSE, out.width='100%'-------------------------------
+#  mapview(geocoded,
+#          label = geocoded$address,
+#          col.regions = "yellow",
+#          map.types = c("Esri.WorldTopoMap"),
+#          legend = FALSE,
+#          homebutton = FALSE
+#  )
 
 ## ----autocomplete, eval=FALSE-------------------------------------------------
 #  suggestions <- autocomplete(addresses, results = 3)
@@ -58,9 +59,6 @@ knitr::kable(head(results), format = "html")
 #  rev_landmarks <- reverse_geocode(poi = poi, results = 3, landmarks = TRUE)
 
 ## ----map_reverse_geocode, eval=FALSE, echo=TRUE, out.width='100%'-------------
-#  # NOTE: This code block is temporarily not evaluated due to an issue of the
-#  # mapview package when plotting multiple SF layers with the new CRS structure of
-#  # version 0.9-0 (see: https://github.com/r-spatial/mapview/issues/271).
 #  m <-
 #    mapview(poi, alpha.region = 0, col.region = "transparent",
 #            label = poi$city, cex = 30, layer.name = "POIs",
